==> zio-aws-mediapackage_3-5.17.104.2-sources.jar: zio/aws/mediapackage/model/RotateIngestEndpointCredentialsRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class RotateIngestEndpointCredentialsRequest(
    id: __string,
    ingestEndpointId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest = {
    import RotateIngestEndpointCredentialsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .ingestEndpointId(__string.unwrap(ingestEndpointId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest.ReadOnly =
    zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest
      .wrap(buildAwsValue())
}
object RotateIngestEndpointCredentialsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest =
      zio.aws.mediapackage.model
        .RotateIngestEndpointCredentialsRequest(id, ingestEndpointId)
    def id: __string
    def ingestEndpointId: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
    def getIngestEndpointId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(ingestEndpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
  ) extends zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest.ReadOnly {
    override val id: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.id())
    override val ingestEndpointId: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.ingestEndpointId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
  ): zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediapackage_3-6.20.97.2-sources.jar: zio/aws/mediapackage/model/RotateIngestEndpointCredentialsRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class RotateIngestEndpointCredentialsRequest(
    id: __string,
    ingestEndpointId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest = {
    import RotateIngestEndpointCredentialsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
      .builder()
      .id(id: java.lang.String)
      .ingestEndpointId(ingestEndpointId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest.ReadOnly =
    zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest
      .wrap(buildAwsValue())
}
object RotateIngestEndpointCredentialsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest =
      zio.aws.mediapackage.model
        .RotateIngestEndpointCredentialsRequest(id, ingestEndpointId)
    def id: __string
    def ingestEndpointId: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
    def getIngestEndpointId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(ingestEndpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
  ) extends zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest.ReadOnly {
    override val id: __string = impl.id(): __string
    override val ingestEndpointId: __string = impl.ingestEndpointId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.RotateIngestEndpointCredentialsRequest
  ): zio.aws.mediapackage.model.RotateIngestEndpointCredentialsRequest.ReadOnly =
    new Wrapper(impl)
}
